pub fn parse_line(line: &str) -> Result<ParsedLine<'_>, ParseError>Expand description
Parses the fixed columns used by merged and filtered fleet log views.
pub fn parse_line(line: &str) -> Result<ParsedLine<'_>, ParseError>Parses the fixed columns used by merged and filtered fleet log views.